import clsx from "clsx";
import { Viewport } from "next";
import { NextIntlClientProvider } from "next-intl";
import { getMessages } from "next-intl/server";
import { Inter as FontSans } from "next/font/google";
import { ReactNode } from "react";
import "../globals.css";

import PageTransitionEffect from "@/components/PageTransitionEffect";
import { Providers } from "./providers";

// 加载字体
const fontSans = FontSans({
    subsets: ["latin"],
    variable: "--font-sans",
});
export const viewport: Viewport = {
    themeColor: [
        { media: "(prefers-color-scheme: light)", color: "white" },
        { media: "(prefers-color-scheme: dark)", color: "black" },
    ],
};

export const metadata = {
    keywords: ["Next.js"],
    description: "Next.js",
    appleWebApp: {
        statusBarStyle: "black",
    },
    formatDetection: {
        email: false,
        address: false,
        telephone: false,
    },
    other: {
        viewport: [
            "width=device-width, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0, viewport-fit=cover",
        ],
    },
};

export default async function LocaleLayout({
    children,
    params: { locale },
}: {
    children: ReactNode;
    params: { locale: string };
}) {
    const messages = await getMessages();

    return (
        <html lang={locale} suppressHydrationWarning>
            <body className={clsx("font-sans", fontSans.variable)}>
                <Providers themeProps={{ defaultTheme: "dark", attribute: "class" }}>
                    <NextIntlClientProvider messages={messages}>
                        <PageTransitionEffect>{children}</PageTransitionEffect>
                    </NextIntlClientProvider>
                </Providers>
            </body>
        </html>
    );
}
