import { create } from 'zustand'
import { devtools, persist, createJSONStorage } from 'zustand/middleware';

interface State {
  lang: string;
  token: string;
  userInfo: any
}

interface Action {
  setLang: (lang: State['lang']) => void;
  setToken: (lang: State['token']) => void;
  setUserInfo: (lang: State['userInfo']) => void;
}

export const useGlobalStore = create<State & Action>()(
  devtools(persist(
    (set) => {
      return {
        lang: 'zh',
        token: '',
        userInfo: '',
        setLang: (lang: State['lang']) => set({
          lang,
        }),
        setToken: (token: State['token']) => set({
          token,
        }),
        setUserInfo: (userInfo: State['userInfo']) => set({
          userInfo,
        }),
      };
    },
    {
      name: 'globalStore',
      storage: createJSONStorage(() => localStorage),
    }
  ),
    { name: 'globalStore' }
  )
)